# размещает по 3 страницы исходного файла на страницу выходного файла")
# Использование: {sys.argv[0]} inFile [outFile]")	
# (C) SSoft z-print@bk.ru")

# если имя выходного файла не указано, оно будет получено автоматически добавлением "combined" к имени исходного
# рекомендуется имена указывать в кавычках, чтобы не было проблем с пробелами

X_POS_MM   = [0, 70, 148] # позиции для размещения по Х в мм
SHEET_W_MM = 297          # ширина выходного листа в мм
SHEET_H_MM = 210          # высота выходного листа в мм

PGONSHEET = len(X_POS_MM) # количество страниц на листе 

from pypdf import PdfReader, PdfWriter
from pypdf._page import PageObject

import sys, os

# пересчитывает мм в пт, в которых работает библиотека
def pt2mm(mm) :
	return mm *2.834

#out sheet size
sheetW = pt2mm(SHEET_W_MM)
sheetH = pt2mm(SHEET_H_MM)
# количество страниц, размещаемых на листе
#  позиции страниц на листе (в пунктах)
PGXPOS = [pt2mm(X_POS_MM[0]), pt2mm(X_POS_MM[1]), pt2mm(X_POS_MM[2])]

# получим имена входного и выходного файла из командной строки
# если имя выходного файла не указано, оно будет получено автоматически добавлением "combined" к имени исходного
# рекомендуется имена указывать в кавычках, чтобы не было проблем с пробелами
if (len(sys.argv) >= 2) :
    inDocName = sys.argv[1]
    if (len(sys.argv) >= 3) :
    	outDocName = sys.argv[2]
    else :
    	outDocName = os.path.splitext(inDocName)[0] + "combined.pdf"
else :
	print(f"{sys.argv[0]} размещает по 3 страницы исходного файла на страницу выходного файла")
	print(f"Использование: {sys.argv[0]} inFile [outFile]")	
	print("(C) SSoft z-print@bk.ru")
	quit()

print (f'конвертируем файл {inDocName} в {outDocName}')

reader = PdfReader(inDocName)
writer = PdfWriter()

for i in range(0, len(reader.pages), PGONSHEET) :
	cleanPage = writer.add_blank_page(sheetW, sheetH)
	try :
		for j in range(len(PGXPOS)) :
			print (f'Обрабатывается страница {i + j} из {len(reader.pages)}')
			cleanPage.merge_translated_page(reader.pages[i + j], PGXPOS[j], 0)
	except:
		print (f"Внимание! Количество страниц в исходном файле не кратно {PGONSHEET}")
		break;
	cleanPage.compress_content_streams(9)

with open(outDocName, 'wb') as outDoc :
	writer.write(outDoc)